pub struct OracleExecution {
pub assessment: Option<OracleAssessment>,
pub delta_parity: Option<DeltaParityAssessment>,
pub temporal_replay: Option<TemporalReplayAssessment>,
pub refutation: Option<OracleRefutationResult>,
}Expand description
Results from running kernel oracle evaluation against compiled constraints.
Fields
assessment: Option<OracleAssessment>delta_parity: Option<DeltaParityAssessment>temporal_replay: Option<TemporalReplayAssessment>refutation: Option<OracleRefutationResult>Implementations
Sourceimpl OracleExecution
impl OracleExecution
Sourcepub fn outcome_summary(&self) -> Option<String>
pub fn outcome_summary(&self) -> Option<String>
Returns a short textual summary of the oracle execution outcome.
Sourcepub fn summary_json(&self) -> Value
pub fn summary_json(&self) -> Value
Returns a JSON summary of the oracle execution outcome.
Sourcepub fn refutation_artifacts(&self) -> Vec<RefutationArtifact>
pub fn refutation_artifacts(&self) -> Vec<RefutationArtifact>
Returns the refutation artifacts emitted by this oracle execution.