Module bootstrap

Module bootstrap 

Structs

BootstrapCurrentState
BootstrapDeltaSummary
BootstrapManifestDelta
BootstrapManifestSnapshot
BootstrapSourceObservation
BootstrapSourceReport
BootstrapSourceSkippedFile
SymbolRecord

Enums

BootstrapRichness
BootstrapSourceRichness

Functions

bootstrap_source_workspace
compute_manifest_delta
Computes the delta between the current bootstrap state and a manifest snapshot.
manifest_from_batch
Rebuilds a manifest snapshot from an imported projection batch when possible.