pub struct BootstrapDeltaSummary {
pub new_file_count: usize,
pub changed_file_count: usize,
pub unchanged_file_count: usize,
pub deleted_file_count: usize,
}Fields
new_file_count: usizechanged_file_count: usizeunchanged_file_count: usizedeleted_file_count: usizeTrait Implementations
Sourceimpl Clone for BootstrapDeltaSummary
impl Clone for BootstrapDeltaSummary
Sourcefn clone(&self) -> BootstrapDeltaSummary
fn clone(&self) -> BootstrapDeltaSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapDeltaSummary
impl Debug for BootstrapDeltaSummary
Sourceimpl Default for BootstrapDeltaSummary
impl Default for BootstrapDeltaSummary
Sourcefn default() -> BootstrapDeltaSummary
fn default() -> BootstrapDeltaSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BootstrapDeltaSummary
impl<'de> Deserialize<'de> for BootstrapDeltaSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BootstrapDeltaSummary
Sourceimpl From<&BootstrapManifestDelta> for BootstrapDeltaSummary
impl From<&BootstrapManifestDelta> for BootstrapDeltaSummary
Sourcefn from(value: &BootstrapManifestDelta) -> Self
fn from(value: &BootstrapManifestDelta) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for BootstrapDeltaSummary
impl JsonSchema for BootstrapDeltaSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BootstrapDeltaSummary
impl PartialEq for BootstrapDeltaSummary
Sourcefn eq(&self, other: &BootstrapDeltaSummary) -> bool
fn eq(&self, other: &BootstrapDeltaSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BootstrapDeltaSummary
impl Serialize for BootstrapDeltaSummary
impl StructuralPartialEq for BootstrapDeltaSummary