pub struct BootstrapManifestSnapshot {
pub manifest_id: String,
pub namespace: String,
pub file_count: usize,
pub chunk_count: usize,
pub symbol_count: usize,
pub degraded_symbol_file_count: usize,
pub richness: BootstrapSourceRichness,
pub chunk_policy: BootstrapChunkPolicyInfo,
pub skipped_files: Vec<BootstrapSourceSkippedFile>,
pub files: Vec<BootstrapManifestFile>,
}Fields
manifest_id: Stringnamespace: Stringfile_count: usizechunk_count: usizesymbol_count: usizedegraded_symbol_file_count: usizerichness: BootstrapSourceRichnesschunk_policy: BootstrapChunkPolicyInfoskipped_files: Vec<BootstrapSourceSkippedFile>files: Vec<BootstrapManifestFile>Trait Implementations
Sourceimpl Clone for BootstrapManifestSnapshot
impl Clone for BootstrapManifestSnapshot
Sourcefn clone(&self) -> BootstrapManifestSnapshot
fn clone(&self) -> BootstrapManifestSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapManifestSnapshot
impl Debug for BootstrapManifestSnapshot
Sourceimpl<'de> Deserialize<'de> for BootstrapManifestSnapshot
impl<'de> Deserialize<'de> for BootstrapManifestSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BootstrapManifestSnapshot
Sourceimpl JsonSchema for BootstrapManifestSnapshot
impl JsonSchema for BootstrapManifestSnapshot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BootstrapManifestSnapshot
impl PartialEq for BootstrapManifestSnapshot
Sourcefn eq(&self, other: &BootstrapManifestSnapshot) -> bool
fn eq(&self, other: &BootstrapManifestSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BootstrapManifestSnapshot