pub struct BootstrapSourceObservation {
pub manifest_id: String,
pub file_count: usize,
pub chunk_count: usize,
pub symbol_count: usize,
pub degraded_symbol_file_count: usize,
pub richness: BootstrapSourceRichness,
pub source_delta: BootstrapSourceDeltaSummary,
pub derived_delta: BootstrapDerivedDeltaSummary,
}Fields
manifest_id: Stringfile_count: usizechunk_count: usizesymbol_count: usizedegraded_symbol_file_count: usizerichness: BootstrapSourceRichnesssource_delta: BootstrapSourceDeltaSummaryderived_delta: BootstrapDerivedDeltaSummaryTrait Implementations
Sourceimpl Clone for BootstrapSourceObservation
impl Clone for BootstrapSourceObservation
Sourcefn clone(&self) -> BootstrapSourceObservation
fn clone(&self) -> BootstrapSourceObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapSourceObservation
impl Debug for BootstrapSourceObservation
Sourceimpl Default for BootstrapSourceObservation
impl Default for BootstrapSourceObservation
Sourcefn default() -> BootstrapSourceObservation
fn default() -> BootstrapSourceObservation
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BootstrapSourceObservation
impl<'de> Deserialize<'de> for BootstrapSourceObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BootstrapSourceObservation
Sourceimpl JsonSchema for BootstrapSourceObservation
impl JsonSchema for BootstrapSourceObservation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BootstrapSourceObservation
impl PartialEq for BootstrapSourceObservation
Sourcefn eq(&self, other: &BootstrapSourceObservation) -> bool
fn eq(&self, other: &BootstrapSourceObservation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BootstrapSourceObservation