pub struct BootstrapSourceReport {Show 22 fields
pub namespace: String,
pub workspace_path: String,
pub scanned_file_count: usize,
pub imported_file_count: usize,
pub skipped_file_count: usize,
pub source_envelope_id: Option<String>,
pub content_digest: Option<String>,
pub import_status: Option<String>,
pub was_duplicate: bool,
pub skipped_files: Vec<BootstrapSourceSkippedFile>,
pub manifest_id: Option<String>,
pub current_manifest_file_count: usize,
pub current_manifest_chunk_count: usize,
pub current_manifest_symbol_count: usize,
pub latest_manifest_only: bool,
pub source_delta: BootstrapSourceDeltaSummary,
pub derived_delta: BootstrapDerivedDeltaSummary,
pub imported_chunk_count: usize,
pub imported_symbol_count: usize,
pub degraded_symbol_file_count: usize,
pub richness: BootstrapSourceRichness,
pub skipped_large_file_count: usize,
}Fields
namespace: Stringworkspace_path: Stringscanned_file_count: usizeimported_file_count: usizeskipped_file_count: usizesource_envelope_id: Option<String>content_digest: Option<String>import_status: Option<String>was_duplicate: boolskipped_files: Vec<BootstrapSourceSkippedFile>manifest_id: Option<String>current_manifest_file_count: usizecurrent_manifest_chunk_count: usizecurrent_manifest_symbol_count: usizelatest_manifest_only: boolsource_delta: BootstrapSourceDeltaSummaryderived_delta: BootstrapDerivedDeltaSummaryimported_chunk_count: usizeimported_symbol_count: usizedegraded_symbol_file_count: usizerichness: BootstrapSourceRichnessskipped_large_file_count: usizeTrait Implementations
Sourceimpl Clone for BootstrapSourceReport
impl Clone for BootstrapSourceReport
Sourcefn clone(&self) -> BootstrapSourceReport
fn clone(&self) -> BootstrapSourceReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BootstrapSourceReport
impl Debug for BootstrapSourceReport
Sourceimpl<'de> Deserialize<'de> for BootstrapSourceReport
impl<'de> Deserialize<'de> for BootstrapSourceReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BootstrapSourceReport
impl JsonSchema for BootstrapSourceReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BootstrapSourceReport
impl RefUnwindSafe for BootstrapSourceReport
impl Send for BootstrapSourceReport
impl Sync for BootstrapSourceReport
impl Unpin for BootstrapSourceReport
impl UnsafeUnpin for BootstrapSourceReport
impl UnwindSafe for BootstrapSourceReport