pub struct SymbolRecord {
pub symbol_id: String,
pub name: String,
pub kind: String,
pub language: String,
pub line_start: usize,
pub line_end: usize,
pub signature: Option<String>,
pub parent_chunk_id: Option<String>,
}Fields
symbol_id: Stringname: Stringkind: Stringlanguage: Stringline_start: usizeline_end: usizesignature: Option<String>parent_chunk_id: Option<String>Trait Implementations
Sourceimpl Clone for SymbolRecord
impl Clone for SymbolRecord
Sourcefn clone(&self) -> SymbolRecord
fn clone(&self) -> SymbolRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymbolRecord
impl Debug for SymbolRecord
Sourceimpl<'de> Deserialize<'de> for SymbolRecord
impl<'de> Deserialize<'de> for SymbolRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolRecord
impl JsonSchema for SymbolRecord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolRecord
impl RefUnwindSafe for SymbolRecord
impl Send for SymbolRecord
impl Sync for SymbolRecord
impl Unpin for SymbolRecord
impl UnsafeUnpin for SymbolRecord
impl UnwindSafe for SymbolRecord