pub fn select_candidate(
candidates: Vec<TargetCandidate>,
history: &PilotHistory,
config: &LoopConfig,
) -> DecisionExpand description
Selects the next executable candidate from the scored target set.
pub fn select_candidate(
candidates: Vec<TargetCandidate>,
history: &PilotHistory,
config: &LoopConfig,
) -> DecisionSelects the next executable candidate from the scored target set.