pub struct GovernanceObservationSummary {
pub effect_preflight_present: bool,
pub assurance_ready: bool,
pub authority_delegation_valid: bool,
pub continuity_incident_active: bool,
pub constitutional_amendment_pending: bool,
pub mechanism_fit_present: bool,
pub degradation_count: usize,
}Expand description
Summary of governance observation included in the receipt.
Fields
effect_preflight_present: boolassurance_ready: boolcontinuity_incident_active: boolconstitutional_amendment_pending: boolmechanism_fit_present: booldegradation_count: usizeTrait Implementations
Sourceimpl Clone for GovernanceObservationSummary
impl Clone for GovernanceObservationSummary
Sourcefn clone(&self) -> GovernanceObservationSummary
fn clone(&self) -> GovernanceObservationSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GovernanceObservationSummary
impl Debug for GovernanceObservationSummary
Sourceimpl<'de> Deserialize<'de> for GovernanceObservationSummary
impl<'de> Deserialize<'de> for GovernanceObservationSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GovernanceObservationSummary
impl JsonSchema for GovernanceObservationSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GovernanceObservationSummary
impl RefUnwindSafe for GovernanceObservationSummary
impl Send for GovernanceObservationSummary
impl Sync for GovernanceObservationSummary
impl Unpin for GovernanceObservationSummary
impl UnsafeUnpin for GovernanceObservationSummary
impl UnwindSafe for GovernanceObservationSummary