pub struct GovernanceReceiptV1 {
pub schema_version: String,
pub gate_result: GovernanceGateResult,
pub observation_summary: GovernanceObservationSummary,
}Expand description
Typed receipt for governance observation within a loop iteration.
Fields
schema_version: Stringgate_result: GovernanceGateResultobservation_summary: GovernanceObservationSummaryTrait Implementations
Sourceimpl Clone for GovernanceReceiptV1
impl Clone for GovernanceReceiptV1
Sourcefn clone(&self) -> GovernanceReceiptV1
fn clone(&self) -> GovernanceReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GovernanceReceiptV1
impl Debug for GovernanceReceiptV1
Sourceimpl<'de> Deserialize<'de> for GovernanceReceiptV1
impl<'de> Deserialize<'de> for GovernanceReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GovernanceReceiptV1
impl JsonSchema for GovernanceReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GovernanceReceiptV1
impl RefUnwindSafe for GovernanceReceiptV1
impl Send for GovernanceReceiptV1
impl Sync for GovernanceReceiptV1
impl Unpin for GovernanceReceiptV1
impl UnsafeUnpin for GovernanceReceiptV1
impl UnwindSafe for GovernanceReceiptV1