pub struct PilotHistory { /* private fields */ }Implementations
Sourceimpl PilotHistory
impl PilotHistory
Sourcepub fn entry(&self, stable_target_key: &str) -> Option<&TargetHistoryEntry>
pub fn entry(&self, stable_target_key: &str) -> Option<&TargetHistoryEntry>
Returns the history entry recorded for a stable target key, if any.
Sourcepub fn retry_count(&self, stable_target_key: &str) -> u32
pub fn retry_count(&self, stable_target_key: &str) -> u32
Returns how many attempts have been recorded for a stable target key.
Sourcepub fn is_exhausted(&self, stable_target_key: &str) -> bool
pub fn is_exhausted(&self, stable_target_key: &str) -> bool
Returns true when a stable target key has been marked exhausted.
Sourcepub fn mark_selected(&mut self, stable_target_key: &str)
pub fn mark_selected(&mut self, stable_target_key: &str)
Marks a stable target key as selected for another attempt.
Sourcepub fn record_outcome(
&mut self,
stable_target_key: &str,
bundle_id: Option<String>,
outcome_signature: String,
max_retries_per_target: u32,
)
pub fn record_outcome( &mut self, stable_target_key: &str, bundle_id: Option<String>, outcome_signature: String, max_retries_per_target: u32, )
Records the outcome of an attempted action for a stable target key.
Sourcepub fn entries(&self) -> impl Iterator<Item = (&String, &TargetHistoryEntry)>
pub fn entries(&self) -> impl Iterator<Item = (&String, &TargetHistoryEntry)>
Iterates over all recorded history entries keyed by stable target key.