pub struct LoopBudgetReceipt {
pub workload_class: String,
pub time_budget_secs: u64,
pub max_iterations: u32,
pub cooldown_secs: u64,
pub max_retries_per_target: u32,
}Expand description
Budget parameters that governed the loop run.
Fields
workload_class: Stringtime_budget_secs: u64max_iterations: u32cooldown_secs: u64max_retries_per_target: u32Trait Implementations
Sourceimpl Clone for LoopBudgetReceipt
impl Clone for LoopBudgetReceipt
Sourcefn clone(&self) -> LoopBudgetReceipt
fn clone(&self) -> LoopBudgetReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoopBudgetReceipt
impl Debug for LoopBudgetReceipt
Sourceimpl<'de> Deserialize<'de> for LoopBudgetReceipt
impl<'de> Deserialize<'de> for LoopBudgetReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoopBudgetReceipt
impl JsonSchema for LoopBudgetReceipt
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoopBudgetReceipt
impl RefUnwindSafe for LoopBudgetReceipt
impl Send for LoopBudgetReceipt
impl Sync for LoopBudgetReceipt
impl Unpin for LoopBudgetReceipt
impl UnsafeUnpin for LoopBudgetReceipt
impl UnwindSafe for LoopBudgetReceipt