pub struct LoopReceipt {Show 22 fields
pub schema_version: String,
pub receipt_id: String,
pub trace_ctx: TraceCtx,
pub attempt_id: AttemptId,
pub namespace: String,
pub workspace_path: String,
pub observation_paths: Option<ObservationPaths>,
pub observation_status: Option<ObservationStatus>,
pub non_authoritative: bool,
pub advisory_only: bool,
pub consumer_only_truth_access: bool,
pub budget: LoopBudgetReceipt,
pub halt_reason: HaltReason,
pub iterations_completed: u32,
pub actions_executed: u32,
pub exports_completed: u32,
pub imports_completed: u32,
pub degraded_iterations: u32,
pub targets_investigated: Vec<String>,
pub started_at: String,
pub finished_at: String,
pub elapsed_seconds: f64,
}Expand description
Typed receipt summarizing a complete loop run for auditing and replay.
Fields
schema_version: Stringreceipt_id: Stringtrace_ctx: TraceCtxattempt_id: AttemptIdnamespace: Stringworkspace_path: Stringobservation_paths: Option<ObservationPaths>observation_status: Option<ObservationStatus>advisory_only: boolconsumer_only_truth_access: boolbudget: LoopBudgetReceipthalt_reason: HaltReasoniterations_completed: u32actions_executed: u32exports_completed: u32imports_completed: u32degraded_iterations: u32targets_investigated: Vec<String>started_at: Stringfinished_at: Stringelapsed_seconds: f64Trait Implementations
Sourceimpl Clone for LoopReceipt
impl Clone for LoopReceipt
Sourcefn clone(&self) -> LoopReceipt
fn clone(&self) -> LoopReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoopReceipt
impl Debug for LoopReceipt
Sourceimpl<'de> Deserialize<'de> for LoopReceipt
impl<'de> Deserialize<'de> for LoopReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoopReceipt
impl JsonSchema for LoopReceipt
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoopReceipt
impl RefUnwindSafe for LoopReceipt
impl Send for LoopReceipt
impl Sync for LoopReceipt
impl Unpin for LoopReceipt
impl UnsafeUnpin for LoopReceipt
impl UnwindSafe for LoopReceipt