pub struct LoopReport {
pub schema_version: String,
pub receipt: LoopReceipt,
pub iterations_completed: u32,
pub actions_executed: u32,
pub exports_completed: u32,
pub imports_completed: u32,
pub halt_reason: HaltReason,
pub targets_investigated: Vec<String>,
pub degraded_iterations: u32,
pub elapsed_seconds: f64,
pub advisory_only_steps: bool,
pub iterations: Vec<LoopIterationReport>,
}Expand description
Top-level report for a complete OODA loop run.
Contains the loop receipt, all iteration reports, and aggregate counters for actions, exports, imports, and degradations.
Fields
schema_version: Stringreceipt: LoopReceiptiterations_completed: u32actions_executed: u32exports_completed: u32imports_completed: u32halt_reason: HaltReasontargets_investigated: Vec<String>degraded_iterations: u32elapsed_seconds: f64advisory_only_steps: booliterations: Vec<LoopIterationReport>Trait Implementations
Sourceimpl Clone for LoopReport
impl Clone for LoopReport
Sourcefn clone(&self) -> LoopReport
fn clone(&self) -> LoopReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoopReport
impl Debug for LoopReport
Sourceimpl<'de> Deserialize<'de> for LoopReport
impl<'de> Deserialize<'de> for LoopReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoopReport
impl JsonSchema for LoopReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LoopReport
impl RefUnwindSafe for LoopReport
impl Send for LoopReport
impl Sync for LoopReport
impl Unpin for LoopReport
impl UnsafeUnpin for LoopReport
impl UnwindSafe for LoopReport