pub struct ForgeEvidenceInventory {
pub available_bundle_count: usize,
}Expand description
Count of Forge evidence bundles available for export.
Fields
available_bundle_count: usizeTrait Implementations
Sourceimpl Clone for ForgeEvidenceInventory
impl Clone for ForgeEvidenceInventory
Sourcefn clone(&self) -> ForgeEvidenceInventory
fn clone(&self) -> ForgeEvidenceInventory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForgeEvidenceInventory
impl Debug for ForgeEvidenceInventory
Sourceimpl<'de> Deserialize<'de> for ForgeEvidenceInventory
impl<'de> Deserialize<'de> for ForgeEvidenceInventory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ForgeEvidenceInventory
Sourceimpl JsonSchema for ForgeEvidenceInventory
impl JsonSchema for ForgeEvidenceInventory
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ForgeEvidenceInventory
impl PartialEq for ForgeEvidenceInventory
Sourcefn eq(&self, other: &ForgeEvidenceInventory) -> bool
fn eq(&self, other: &ForgeEvidenceInventory) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ForgeEvidenceInventory
impl Serialize for ForgeEvidenceInventory
impl StructuralPartialEq for ForgeEvidenceInventory