pub struct ObservationDegradation {
pub kind: String,
pub detail: String,
}Expand description
A degradation detected during scope observation.
Fields
kind: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ObservationDegradation
impl Clone for ObservationDegradation
Sourcefn clone(&self) -> ObservationDegradation
fn clone(&self) -> ObservationDegradation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservationDegradation
impl Debug for ObservationDegradation
Sourceimpl<'de> Deserialize<'de> for ObservationDegradation
impl<'de> Deserialize<'de> for ObservationDegradation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObservationDegradation
Sourceimpl JsonSchema for ObservationDegradation
impl JsonSchema for ObservationDegradation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObservationDegradation
impl PartialEq for ObservationDegradation
Sourcefn eq(&self, other: &ObservationDegradation) -> bool
fn eq(&self, other: &ObservationDegradation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservationDegradation
impl Serialize for ObservationDegradation
impl StructuralPartialEq for ObservationDegradation