pub struct ObservationPaths {
pub namespace: String,
pub workspace_path: String,
pub memory_dir: String,
pub forge_db_path: String,
pub memory_dir_state: PathAvailability,
pub forge_db_state: PathAvailability,
}Expand description
Resolved filesystem paths and their availability for a configured namespace.
Fields
namespace: Stringworkspace_path: Stringmemory_dir: Stringforge_db_path: Stringmemory_dir_state: PathAvailabilityforge_db_state: PathAvailabilityTrait Implementations
Sourceimpl Clone for ObservationPaths
impl Clone for ObservationPaths
Sourcefn clone(&self) -> ObservationPaths
fn clone(&self) -> ObservationPaths
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservationPaths
impl Debug for ObservationPaths
Sourceimpl<'de> Deserialize<'de> for ObservationPaths
impl<'de> Deserialize<'de> for ObservationPaths
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObservationPaths
Sourceimpl JsonSchema for ObservationPaths
impl JsonSchema for ObservationPaths
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObservationPaths
impl PartialEq for ObservationPaths
Sourcefn eq(&self, other: &ObservationPaths) -> bool
fn eq(&self, other: &ObservationPaths) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservationPaths
impl Serialize for ObservationPaths
impl StructuralPartialEq for ObservationPaths