pub struct ObservationStatus {Show 13 fields
pub disposition: ObservationDisposition,
pub namespace_queried: String,
pub resolved_workspace_path: String,
pub supported_file_count: usize,
pub imported_file_count: usize,
pub imported_chunk_count: usize,
pub imported_symbol_count: usize,
pub bootstrap_richness: BootstrapRichness,
pub available_forge_bundle_count: usize,
pub import_record_disposition: ImportRecordDisposition,
pub import_records_found: bool,
pub exact_next_step: String,
pub other_import_namespaces: Vec<String>,
}Expand description
Machine-readable status summary for a namespace observation.
Includes import disposition, file counts, and a human-readable
exact_next_step describing what the operator should do next.
Fields
disposition: ObservationDispositionnamespace_queried: Stringresolved_workspace_path: Stringsupported_file_count: usizeimported_file_count: usizeimported_chunk_count: usizeimported_symbol_count: usizebootstrap_richness: BootstrapRichnessavailable_forge_bundle_count: usizeimport_record_disposition: ImportRecordDispositionimport_records_found: boolexact_next_step: Stringother_import_namespaces: Vec<String>Trait Implementations
Sourceimpl Clone for ObservationStatus
impl Clone for ObservationStatus
Sourcefn clone(&self) -> ObservationStatus
fn clone(&self) -> ObservationStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObservationStatus
impl Debug for ObservationStatus
Sourceimpl<'de> Deserialize<'de> for ObservationStatus
impl<'de> Deserialize<'de> for ObservationStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObservationStatus
Sourceimpl JsonSchema for ObservationStatus
impl JsonSchema for ObservationStatus
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ObservationStatus
impl PartialEq for ObservationStatus
Sourcefn eq(&self, other: &ObservationStatus) -> bool
fn eq(&self, other: &ObservationStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ObservationStatus
impl Serialize for ObservationStatus
impl StructuralPartialEq for ObservationStatus