pub struct SourceInventory {
pub supported_file_count: usize,
pub imported_current_state: BootstrapCurrentState,
}Expand description
Count of supported source files and imported state for the workspace.
Fields
supported_file_count: usizeimported_current_state: BootstrapCurrentStateTrait Implementations
Sourceimpl Clone for SourceInventory
impl Clone for SourceInventory
Sourcefn clone(&self) -> SourceInventory
fn clone(&self) -> SourceInventory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceInventory
impl Debug for SourceInventory
Sourceimpl<'de> Deserialize<'de> for SourceInventory
impl<'de> Deserialize<'de> for SourceInventory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SourceInventory
Sourceimpl JsonSchema for SourceInventory
impl JsonSchema for SourceInventory
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SourceInventory
impl PartialEq for SourceInventory
Sourcefn eq(&self, other: &SourceInventory) -> bool
fn eq(&self, other: &SourceInventory) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SourceInventory
impl Serialize for SourceInventory
impl StructuralPartialEq for SourceInventory