pub struct DecisionAudit {
pub stable_target_key: String,
pub canonical_case_class: CanonicalCaseClass,
pub budget_class: BudgetClass,
pub target_exactness: ExactnessLevelV1,
pub cheapest_admissible: Option<LawfulStepKind>,
pub fallback_steps: Vec<PlannedStep>,
pub blocked_steps: Vec<BlockedStepRecord>,
pub cheap_check_ladder: Vec<CheapCheckStatusV1>,
pub advisory_only: bool,
}Expand description
Audit record capturing the decision rationale for a selected target.
Fields
stable_target_key: Stringcanonical_case_class: CanonicalCaseClassbudget_class: BudgetClasstarget_exactness: ExactnessLevelV1cheapest_admissible: Option<LawfulStepKind>fallback_steps: Vec<PlannedStep>blocked_steps: Vec<BlockedStepRecord>cheap_check_ladder: Vec<CheapCheckStatusV1>advisory_only: boolTrait Implementations
Sourceimpl Clone for DecisionAudit
impl Clone for DecisionAudit
Sourcefn clone(&self) -> DecisionAudit
fn clone(&self) -> DecisionAudit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionAudit
impl Debug for DecisionAudit
Sourceimpl<'de> Deserialize<'de> for DecisionAudit
impl<'de> Deserialize<'de> for DecisionAudit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DecisionAudit
Sourceimpl JsonSchema for DecisionAudit
impl JsonSchema for DecisionAudit
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionAudit
impl PartialEq for DecisionAudit
Sourcefn eq(&self, other: &DecisionAudit) -> bool
fn eq(&self, other: &DecisionAudit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecisionAudit
impl Serialize for DecisionAudit
impl StructuralPartialEq for DecisionAudit