pub struct ExecutionLineageReceipt {
pub case_id: String,
pub plan_id: String,
pub attempt_id: String,
pub target_key: String,
pub execution_context_ref: String,
pub consumed_artifact_refs: Vec<String>,
pub produced_artifact_refs: Vec<String>,
pub degradation_markers: Vec<String>,
pub outcome_summary: String,
}Expand description
Lineage receipt linking a verification case to its consumed and produced artifacts.
Fields
case_id: Stringplan_id: Stringattempt_id: Stringtarget_key: Stringexecution_context_ref: Stringconsumed_artifact_refs: Vec<String>produced_artifact_refs: Vec<String>degradation_markers: Vec<String>outcome_summary: StringTrait Implementations
Sourceimpl Clone for ExecutionLineageReceipt
impl Clone for ExecutionLineageReceipt
Sourcefn clone(&self) -> ExecutionLineageReceipt
fn clone(&self) -> ExecutionLineageReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionLineageReceipt
impl Debug for ExecutionLineageReceipt
Sourceimpl<'de> Deserialize<'de> for ExecutionLineageReceipt
impl<'de> Deserialize<'de> for ExecutionLineageReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionLineageReceipt
Sourceimpl JsonSchema for ExecutionLineageReceipt
impl JsonSchema for ExecutionLineageReceipt
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExecutionLineageReceipt
impl PartialEq for ExecutionLineageReceipt
Sourcefn eq(&self, other: &ExecutionLineageReceipt) -> bool
fn eq(&self, other: &ExecutionLineageReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExecutionLineageReceipt
impl Serialize for ExecutionLineageReceipt
impl StructuralPartialEq for ExecutionLineageReceipt