pub struct PlannedStep {
pub step_kind: LawfulStepKind,
pub cost_rank: u8,
pub required_artifact_families: Vec<String>,
}Expand description
A single step in a verification plan with its cost and artifact requirements.
Fields
step_kind: LawfulStepKindcost_rank: u8required_artifact_families: Vec<String>Trait Implementations
Sourceimpl Clone for PlannedStep
impl Clone for PlannedStep
Sourcefn clone(&self) -> PlannedStep
fn clone(&self) -> PlannedStep
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlannedStep
impl Debug for PlannedStep
Sourceimpl<'de> Deserialize<'de> for PlannedStep
impl<'de> Deserialize<'de> for PlannedStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlannedStep
Sourceimpl JsonSchema for PlannedStep
impl JsonSchema for PlannedStep
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlannedStep
impl PartialEq for PlannedStep
Sourcefn eq(&self, other: &PlannedStep) -> bool
fn eq(&self, other: &PlannedStep) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlannedStep
impl Serialize for PlannedStep
impl StructuralPartialEq for PlannedStep