pub struct VerificationPlanArtifact {Show 16 fields
pub schema_version: String,
pub plan_id: String,
pub proof_profile: Option<ProofProfileV1>,
pub cheapest_checks: Vec<String>,
pub cheap_check_ladder: Vec<CheapCheckStatusV1>,
pub replay_recipe: Vec<String>,
pub replay_preconditions: Vec<String>,
pub blocked_checks: Vec<String>,
pub proof_obligations_remaining: Vec<String>,
pub admissible_evidence: Vec<String>,
pub refutation_suggestions: Vec<String>,
pub degradation_flags: Vec<String>,
pub policy_blockers: Vec<String>,
pub promotion_blocked_on_missing_proof: bool,
pub target_exactness: ExactnessLevelV1,
pub expires_at: Option<String>,
}Expand description
Serializable verification plan artifact emitted per iteration.
Captures proof obligations, admissible evidence, cheapest check ladders, and policy blockers for downstream adjudication.
Fields
schema_version: Stringplan_id: Stringproof_profile: Option<ProofProfileV1>cheapest_checks: Vec<String>cheap_check_ladder: Vec<CheapCheckStatusV1>replay_recipe: Vec<String>replay_preconditions: Vec<String>blocked_checks: Vec<String>proof_obligations_remaining: Vec<String>admissible_evidence: Vec<String>refutation_suggestions: Vec<String>degradation_flags: Vec<String>policy_blockers: Vec<String>promotion_blocked_on_missing_proof: booltarget_exactness: ExactnessLevelV1expires_at: Option<String>Trait Implementations
Sourceimpl Clone for VerificationPlanArtifact
impl Clone for VerificationPlanArtifact
Sourcefn clone(&self) -> VerificationPlanArtifact
fn clone(&self) -> VerificationPlanArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerificationPlanArtifact
impl Debug for VerificationPlanArtifact
Sourceimpl<'de> Deserialize<'de> for VerificationPlanArtifact
impl<'de> Deserialize<'de> for VerificationPlanArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerificationPlanArtifact
Sourceimpl JsonSchema for VerificationPlanArtifact
impl JsonSchema for VerificationPlanArtifact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerificationPlanArtifact
impl PartialEq for VerificationPlanArtifact
Sourcefn eq(&self, other: &VerificationPlanArtifact) -> bool
fn eq(&self, other: &VerificationPlanArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerificationPlanArtifact
impl Serialize for VerificationPlanArtifact
impl StructuralPartialEq for VerificationPlanArtifact